@@ -31,8 +31,6 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-$this->css();
-
 $surname = stripslashes($this->profile->get('surname'));
 $givenName = stripslashes($this->profile->get('givenName'));
 $middleName = stripslashes($this->profile->get('middleName'));
@@ -48,16 +46,17 @@ if (!$surname) {
 	}
 }
 
-$html  = '<header id="content-header">'."\n";
+$html  = '<div id="content-header">'."\n";
 $html .= "\t".'<h2>'.$this->title.'</h2>'."\n";
+$html .= '</div><!-- / #content-header-extra -->'."\n";
+
+
 $html .= '<div id="content-header-extra">'."\n";
 $html .= "\t".'<ul id="useroptions">'."\n";
 $html .= "\t\t".'<li class="last"><a href="'.JRoute::_('index.php?option='.$this->option.'&task=cancel&id='. $this->profile->get('uidNumber')) .'">'.JText::_('CANCEL').'</a></li>'."\n";
 $html .= "\t".'</ul>'."\n";
 $html .= '</div><!-- / #content-header-extra -->'."\n";
-$html .= '</header><!-- / #content-header-extra -->'."\n";
-
-$html .= '<section class="main section">'."\n";
+$html .= '<div class="main section">'."\n"; 
 
 
 $html .= "\t".'<form id="hubForm" class="edit-profile" method="post" action="index.php" enctype="multipart/form-data">'."\n";
@@ -86,7 +85,7 @@ if ($this->authorized === 'admin') {
 //$html .= "\t\t".'<p class="help">'.JText::_('E-mail may be changed with <a href="/hub/registration/edit">this form</a>.')."\n";
 //$html .= "\t\t".'<p class="help">'.JText::_('Passwords can be changed with <a href="'.JRoute::_('index.php?option='.$this->option.a.'id='.$this->profile->get('uidNumber').a.'task=changepassword').'">this form</a>.').'</p>'."\n";
 
-//$mwconfig = JComponentHelper::getParams( 'com_mw' );
+//$mwconfig =& JComponentHelper::getParams( 'com_mw' );
 //$enabled = $mwconfig->get('mw_on');
 //if ($enabled) {
 //	$html .= "\t\t".'<p class="help">'.JText::_('Request for more storage or sessions may be made with <a href="'.JRoute::_('index.php?option='.$this->option.a.'id='.$this->profile->get('uidNumber').a.'task=raiselimit').'">this form</a>.').'</p>'."\n";
@@ -109,7 +108,7 @@ $html .= "\t\t".'</label>'."\n";
 
 if ($this->registration->Fullname != REG_HIDE) {
 	$required = ($this->registration->Fullname == REG_REQUIRED) ? ' <span class="required">'.JText::_('REQUIRED').'</span>' : '';
-	$message = (!empty($this->xregistration->_invalid['name'])) ? '<p class="error">' . $this->xregistration->_invalid['name'] . '</p>' : '';
+	$message = (!empty($this->xregistration->_invalid['name'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['name']) : '';
 	$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 	$html .= "\t\t".'<div class="threeup group">'."\n";
@@ -131,19 +130,19 @@ if ($this->registration->Fullname != REG_HIDE) {
 	$html .= $message;
 }
 
-if ($this->registration->Email != REG_HIDE || $this->registration->ConfirmEmail != REG_HIDE)
-{
+if ($this->registration->Email != REG_HIDE
+ || $this->registration->ConfirmEmail != REG_HIDE) {
 	$html .= "\t\t".'<div class="group twoup">'."\n";
 
 	// Email
 	if ($this->registration->Email != REG_HIDE) {
 		$required = ($this->registration->Email == REG_REQUIRED) ? '<span class="required">'.JText::_('required').'</span>' : '';
-		$message = (!empty($this->xregistration->_invalid['email'])) ? '<span class="error">' . $this->xregistration->_invalid['email'] . '</span>' : '';
+		$message = (!empty($this->xregistration->_invalid['email'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['email'],'span') : '';
 		$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 		$html .= "\t\t\t".'<label '.$fieldclass.'>'."\n";
 		$html .= "\t\t\t\t".JText::_('Valid E-mail').': '.$required."\n";
-		$html .= "\t\t\t\t".'<input name="email" id="email" type="text" value="'.$this->escape($this->profile->get('email')).'" />'."\n";
+		$html .= "\t\t\t\t".'<input name="email" id="email" type="text" value="'.htmlentities($this->profile->get('email'),ENT_COMPAT,'UTF-8').'" />'."\n";
 		$html .= ($message) ? "\t\t\t\t".$message."\n" : '';
 		$html .= "\t\t\t".'</label>'."\n";
 	}
@@ -156,7 +155,7 @@ if ($this->registration->Email != REG_HIDE || $this->registration->ConfirmEmail
 			$confirmEmail = '';
 		}
 		if (!empty($this->xregistration->_invalid['confirmEmail'])) {
-			$message = '<span class="error">' . $this->xregistration->_invalid['confirmEmail'] . '</span>';
+			$message = Hubzero_View_Helper_Html::error($this->xregistration->_invalid['confirmEmail'],'span');
 		}
 
 		$required = ($this->registration->ConfirmEmail == REG_REQUIRED) ? '<span class="required">'.JText::_('required').'</span>' : '';
@@ -164,7 +163,7 @@ if ($this->registration->Email != REG_HIDE || $this->registration->ConfirmEmail
 
 		$html .= "\t\t\t".'<label'.$fieldclass.'>'."\n";
 		$html .= "\t\t\t\t".JText::_('Confirm E-mail').': '.$required."\n";
-		$html .= "\t\t\t\t".'<input name="email2" id="email2" type="text" value="'.$this->escape($confirmEmail).'" />'."\n";
+		$html .= "\t\t\t\t".'<input name="email2" id="email2" type="text" value="'.htmlentities($confirmEmail,ENT_COMPAT,'UTF-8').'" />'."\n";
 		$html .= ($message) ? "\t\t\t\t".$message."\n" : '';
 		$html .= "\t\t\t".'</label>'."\n";
 	}
@@ -172,50 +171,30 @@ if ($this->registration->Email != REG_HIDE || $this->registration->ConfirmEmail
 	$html .= "\t\t".'</div>'."\n";
 
 	if ($this->registration->Email != REG_HIDE) {
-		$html .= "\t\t".'<p class="warning">Important! If you change your E-Mail address you <strong>must</strong> confirm receipt of the confirmation e-mail in order to re-activate your account.</p>';
+		$html .= "\t\t".Hubzero_View_Helper_Html::warning('Important! If you change your E-Mail address you <strong>must</strong> confirm receipt of the confirmation e-mail in order to re-activate your account.');
 	}
 }
 
-if ($this->registration->ORCID != REG_HIDE) {
-	$required = ($this->registration->ORCID == REG_REQUIRED) ? '<span class="required">'.JText::_('REQUIRED').'</span>' : '';
-	$message = (!empty($this->xregistration->_invalid['orcid'])) ? '<p class="error">' . $this->xregistration->_invalid['orcid'] . '</p>' : '';
-	$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
-
-	$html .= '<div class="grid">
-				<div class="col span9">
-					<label'.$fieldclass.'>' .
-						JText::_('ORCID').': '.$required. '
-						<input type="text" name="orcid" value="'. $this->escape(stripslashes($this->profile->get('orcid'))) .'" />
-						' . $message . '
-					</label>
-				</div>
-				<div class="col span3 omega">
-					<a class="btn icon-search" id="orcid-fetch" href="' . JRoute::_('index.php?option=' . $this->option . '&controller=orcid') . '">' . JText::_('Find your ID') . '</a>
-				</div>
-			</div>
-			<p>ORCID provides a persistent digital identifier that distinguishes you from every other researcher and supports automated linkages between you and your professional activities ensuring that your work is recognized. <a rel="external" href="http://orcid.org">Find out more.</a></p>'."\n";
-}
-
 if ($this->registration->URL != REG_HIDE) {
 	$required = ($this->registration->URL == REG_REQUIRED) ? '<span class="required">'.JText::_('REQUIRED').'</span>' : '';
-	$message = (!empty($this->xregistration->_invalid['web'])) ? '<p class="error">' . $this->xregistration->_invalid['web'] . '</p>' : '';
+	$message = (!empty($this->xregistration->_invalid['web'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['web']) : '';
 	$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 	$html .= "\t\t".'<label'.$fieldclass.'>'."\n";
 	$html .= "\t\t\t".JText::_('WEBSITE').': '.$required."\n";
-	$html .= "\t\t\t".'<input type="text" name="web" value="'. $this->escape(stripslashes($this->profile->get('url'))) .'" />'."\n";
+	$html .= "\t\t\t".'<input type="text" name="web" value="'. stripslashes($this->profile->get('url')) .'" /></td>'."\n";
 	$html .= $message;
 	$html .= "\t\t".'</label>'."\n";
 }
 
 if ($this->registration->Phone != REG_HIDE) {
 	$required = ($this->registration->Phone == REG_REQUIRED) ? '<span class="required">'.JText::_('REQUIRED').'</span>' : '';
-	$message = (!empty($this->xregistration->_invalid['phone'])) ? '<p class="error">' . $this->xregistration->_invalid['phone'] . '</p>' : '';
+	$message = (!empty($this->xregistration->_invalid['phone'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['phone']) : '';
 	$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 	$html .= "\t\t".'<label'.$fieldclass.'>'."\n";
 	$html .= "\t\t\t".JText::_('Phone').': '.$required."\n";
-	$html .= "\t\t\t".'<input type="text" name="phone" value="'. $this->escape(stripslashes($this->profile->get('phone'))) .'" />'."\n";
+	$html .= "\t\t\t".'<input type="text" name="phone" value="'. stripslashes($this->profile->get('phone')) .'" /></td>'."\n";
 	$html .= $message;
 	$html .= "\t\t".'</label>'."\n";
 }
@@ -226,7 +205,7 @@ $html .= "\t\t".'<legend>'.JText::_('Personal Information').'</legend>'."\n";
 
 if ($this->registration->Employment != REG_HIDE) {
 	$required = ($this->registration->Employment == REG_REQUIRED) ? '<span class="required">'.JText::_('REQUIRED').'</span>' : '';
-	$message = (!empty($this->xregistration->_invalid['orgtype'])) ? '<p class="error">' . $this->xregistration->_invalid['orgtype'] . '</p>' : '';
+	$message = (!empty($this->xregistration->_invalid['orgtype'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['orgtype']) : '';
 	$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 	$orgtype = stripslashes($this->profile->get('orgtype'));
@@ -298,7 +277,7 @@ if ($this->registration->Employment != REG_HIDE) {
 
 if ($this->registration->Organization != REG_HIDE) {
 	$required = ($this->registration->Organization == REG_REQUIRED) ? '<span class="required">'.JText::_('REQUIRED').'</span>' : '';
-	$message = (!empty($this->xregistration->_invalid['org'])) ? '<p class="error">' . $this->xregistration->_invalid['org'] . '</p>' : '';
+	$message = (!empty($this->xregistration->_invalid['org'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['org']) : '';
 	$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 	$organization = stripslashes($this->profile->get('organization'));
@@ -306,59 +285,62 @@ if ($this->registration->Organization != REG_HIDE) {
 	$org_known = 0;
 
 	//$orgs = array();
-	include_once( JPATH_ROOT.DS.'administrator' . DS .'components'.DS.'com_members'.DS.'tables'.DS.'organization.php' );
-	$database = JFactory::getDBO();
+	//include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_hub'.DS.'xorganization.php' );
+	include_once( JPATH_ROOT.DS.'components'.DS.'com_register'.DS.'tables'.DS.'organization.php' );
+	$database =& JFactory::getDBO();
+	//$xo = new XOrganization( $database );
+	$xo = new RegisterOrganization( $database );
+	$orgs = $xo->getOrgs();
 
-	$xo = new MembersTableOrganization($database);
-	$orgs = $xo->find('list');
+	if (count($orgs) <= 0) {
+		$orgs[0] = 'Purdue University';
+		$orgs[1] = 'University of Pennsylvania';
+		$orgs[2] = 'University of California at Berkeley';
+		$orgs[3] = 'Vanderbilt University';
+	}
 
 	foreach ($orgs as $org)
 	{
-		$org_known = ($org->organization == $organization) ? 1 : 0;
+		$org_known = ($org == $organization) ? 1 : 0;
 	}
 
 	$html .= "\t\t".'<label'.$fieldclass.'>'."\n";
 	$html .= "\t\t\t".JText::_('ORG').': '.$required."\n";
 	$html .= "\t\t\t".'<select name="org">'."\n";
 	$html .= "\t\t\t\t".'<option value=""';
-	if (!$org_known)
-	{
+	if (!$org_known) {
 		$html .= ' selected="selected"';
 	}
 	$html .= '>';
-	if ($org_known)
-	{
+	if ($org_known) {
 		$html .= JText::_('(other / none)');
-	}
-	else
-	{
+	} else {
 		$html .= JText::_('(select from list or enter below)');
 	}
 	$html .= '</option>'."\n";
 	foreach ($orgs as $org)
 	{
-		$html .= "\t\t\t\t".'<option value="'. $this->escape($org->organization) .'"';
-		if ($org->organization == $organization)
-		{
+		$html .= "\t\t\t\t".'<option value="'. htmlentities($org,ENT_COMPAT,'UTF-8') .'"';
+		if ($org == $organization) {
 			$orgtext = '';
 			$html .= ' selected="selected"';
 		}
-		$html .= '>' . $this->escape($org->organization) . '</option>'."\n";
+		$html .= '>' . htmlentities($org) . '</option>'."\n";
 	}
 	$html .= "\t\t\t".'</select>'."\n";
 	$html .= $message;
 	$html .= "\t\t".'</label>'."\n";
 	$html .= "\t\t".'<label for="orgtext" id="orgtextlabel">'.JText::_('Enter organization below').'</label>'."\n";
-	$html .= "\t\t".'<input type="text" name="orgtext" id="orgtext" value="'. $this->escape($orgtext) .'" />'."\n";
+	$html .= "\t\t".'<input type="text" name="orgtext" id="orgtext" value="'. htmlentities($orgtext,ENT_COMPAT,'UTF-8') .'" />'."\n";
 }
 
 if ($this->registration->Interests != REG_HIDE) {
 	$required = ($this->registration->Interests == REG_REQUIRED) ? '<span class="required">'.JText::_('REQUIRED').'</span>' : '';
-	$message = (!empty($this->xregistration->_invalid['interests'])) ? '<p class="error">' . $this->xregistration->_invalid['interests'] . '</p>' : '';
+	$message = (!empty($this->xregistration->_invalid['interests'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['interests']) : '';
 	$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 	JPluginHelper::importPlugin( 'hubzero' );
-	$dispatcher = JDispatcher::getInstance();
+	$dispatcher =& JDispatcher::getInstance();
 	$tf = $dispatcher->trigger( 'onGetMultiEntry', array(array('tags', 'tags', 'actags','',stripslashes($this->tags))) );
 
 	$html .= "\t\t".'<label'.$fieldclass.'>'."\n";
@@ -373,28 +355,38 @@ if ($this->registration->Interests != REG_HIDE) {
 	$html .= "\t\t".'</label>'."\n";
 }
 
+ximport('Hubzero_Wiki_Editor');
+$editor =& Hubzero_Wiki_Editor::getInstance();
+
 $html .= "\t\t".'<label for="profilebio">'."\n";
 $html .= "\t\t\t".JText::_('BIO').':'."\n";
-$html .= "\t\t\t".\JFactory::getEditor()->display('profile[bio]', $this->escape(stripslashes($this->profile->getBio('raw'))), '', '', 35, 10, false, 'profilebio', null, null, array('class' => 'minimal no-footer'));
-$html .= "\t\t\t".'<span class="hint"><a class="popup" href="'.JRoute::_('index.php?option=com_wiki&scope=&pagename=Help:WikiFormatting').'">Wiki formatting</a> is allowed for Bios.</span>'."\n";
+$html .= "\t\t\t".$editor->display('profile[bio]', 'profilebio', stripslashes($this->profile->get('bio')), '', '40', '10');
+$html .= "\t\t\t".'<span class="hint"><a class="popup" href="'.JRoute::_('index.php?option=com_topics&scope=&pagename=Help:WikiFormatting').'">Wiki formatting</a> is allowed for Bios.</span>'."\n";
 $html .= "\t\t".'</label>'."\n";
 $html .= "\t".'</fieldset><div class="clear"></div>'."\n";
 
-if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residency != REG_HIDE || $this->registration->Sex != REG_HIDE || $this->registration->Disability != REG_HIDE || $this->registration->Hispanic != REG_HIDE || $this->registration->Race != REG_HIDE)
+if ($this->registration->Citizenship != REG_HIDE
+ || $this->registration->Residency != REG_HIDE
+ || $this->registration->Sex != REG_HIDE
+ || $this->registration->Disability != REG_HIDE
+ || $this->registration->Hispanic != REG_HIDE
+ || $this->registration->Race != REG_HIDE)
 {
-	$html .= "\t".'<fieldset>'."\n";
+	$html .= t.'<fieldset>'."\n";
 	$html .= "\t\t".'<legend>'.JText::_('Demographics').'</legend>'."\n";
 
-	if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residency != REG_HIDE) {
-		$countries = \Hubzero\Geocode\Geocode::countries();
+	if ($this->registration->Citizenship != REG_HIDE
+	 || $this->registration->Residency != REG_HIDE) {
+		ximport('Hubzero_Geo');
+		$countries = Hubzero_Geo::getcountries();
 	}
 
 	if ($this->registration->Citizenship != REG_HIDE) {
 		$required = ($this->registration->Citizenship == REG_REQUIRED) ? ' <span class="required">'.JText::_('REQUIRED').'</span>' : '';
-		$message = (!empty($this->xregistration->_invalid['countryorigin'])) ? '<p class="error">' . $this->xregistration->_invalid['countryorigin'] . '</p>' : '';
+		$message = (!empty($this->xregistration->_invalid['countryorigin'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['countryorigin']) : '';
 		$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 
-		$countryorigin = strtoupper($this->profile->get('countryorigin'));
+		$countryorigin = $this->profile->get('countryorigin');
 
 		$html .= "\t\t".'<fieldset'.$fieldclass.'>'."\n";
 		$html .= "\t\t\t".'<legend>'.JText::_('Are you a Legal Citizen or Permanent Resident of the <abbr title="United States">US</abbr>?').$required.'</legend>'."\n";
@@ -416,12 +408,12 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 		}
 		foreach ($countries as $country)
 		{
-			if ($country->code != 'US') {
-				$html .= "\t\t\t\t".' <option value="' . $country->code . '"';
-				if ($countryorigin == strtoupper($country->code)) {
+			if ($country['code'] != 'US') {
+				$html .= "\t\t\t\t".' <option value="' . $country['code'] . '"';
+				if ($countryorigin == $country['code']) {
 					$html .= ' selected="selected"';
 				}
-				$html .= '>' . $this->escape($country->name) . '</option>'."\n";
+				$html .= '>' . htmlentities($country['name'],ENT_COMPAT,'UTF-8') . '</option>'."\n";
 			}
 		}
 		$html .= "\t\t\t\t".'</select></label>'."\n";
@@ -430,10 +422,10 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 
 	if ($this->registration->Residency != REG_HIDE) {
 		$required = ($this->registration->Residency == REG_REQUIRED) ? ' <span class="required">'.JText::_('REQUIRED').'</span>' : '';
-		$message = (!empty($this->xregistration->_invalid['countryresident'])) ? '<p class="error">' . $this->xregistration->_invalid['countryresident'] . '</p>' : '';
+		$message = (!empty($this->xregistration->_invalid['countryresident'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['countryresident']) : '';
 		$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 
-		$countryresident = strtoupper($this->profile->get('countryresident'));
+		$countryresident = $this->profile->get('countryresident');
 
 		$html .= "\t\t".'<fieldset'.$fieldclass.'>';
 		$html .= "\t\t\t".'<legend>'.JText::_('Do you Currently Live in the <abbr title="United States">US</abbr>?').$required.'</legend>'."\n";
@@ -455,12 +447,12 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 		}
 		foreach ($countries as $country)
 		{
-			if (strcasecmp($country->code,"US") != 0) {
-				$html .= "\t\t\t"."\t\t".'<option value="' . $country->code . '"';
-				if ($countryresident == strtoupper($country->code)) {
+			if (strcasecmp($country['code'],"US") != 0) {
+				$html .= "\t\t\t"."\t\t".'<option value="' . $country['code'] . '"';
+				if (strcasecmp($countryresident,$country['code']) == 0) {
 					$html .= ' selected="selected"';
 				}
-				$html .= '>' . $this->escape($country->name) . '</option>'."\n";
+				$html .= '>' . htmlentities($country['name'],ENT_COMPAT,'UTF-8') . '</option>'."\n";
 			}
 		}
 		$html .= "\t\t\t\t".'</select></label>'."\n";
@@ -468,7 +460,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 	}
 
 	if ($this->registration->Sex != REG_HIDE) {
-		$message = (!empty($this->xregistration->_invalid['countryresident'])) ? '<p class="error">' . $this->xregistration->_invalid['countryresident'] . '</p>' : '';
+		$message = (!empty($this->xregistration->_invalid['countryresident'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['countryresident']) : '';
 		$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 		$required = ($this->registration->Sex == REG_REQUIRED) ? ' <span class="required">'.JText::_('REQUIRED').'</span>' : '';
 
@@ -490,7 +482,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 
 	// Disability
 	if ($this->registration->Disability != REG_HIDE) {
-		$message = (!empty($this->xregistration->_invalid['disability'])) ? '<p class="error">' . $this->xregistration->_invalid['disability'] . '</p>' : '';
+		$message = (!empty($this->xregistration->_invalid['disability'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['disability']) : '';
 		$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 		$required = ($this->registration->Disability == REG_REQUIRED) ? ' <span class="required">'.JText::_('REQUIRED').'</span>' : '';
 
@@ -555,7 +547,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 		}
 		$html .= '/> '.JText::_('Vocal / Speech Disability').'</label>'."\n";
 		$html .= "\t\t\t\t".'<label>'.JText::_('Other (please specify)').':'."\n";
-		$html .= "\t\t\t\t".'<input name="disabilityother" id="disabilityother" type="text" value="'. $this->escape($disabilityother) .'" /></label>'."\n";
+		$html .= "\t\t\t\t".'<input name="disabilityother" id="disabilityother" type="text" value="'. htmlentities($disabilityother,ENT_COMPAT,'UTF-8') .'" /></label>'."\n";
 		$html .= "\t\t\t".'</fieldset>'."\n";
 		$html .= "\t\t\t".'<label><input type="radio" class="option" name="disability" id="disabilityno" value="no"';
 		if (in_array('no', $disabilities)) {
@@ -572,7 +564,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 
 	// Hispanic
 	if ($this->registration->Hispanic != REG_HIDE) {
-		$message = (!empty($this->xregistration->_invalid['hispanic'])) ? '<p class="error">' . $this->xregistration->_invalid['hispanic'] . '</p>' : '';
+		$message = (!empty($this->xregistration->_invalid['hispanic'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['hispanic']) : '';
 		$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 		$required = ($this->registration->Hispanic == REG_REQUIRED) ? ' <span class="required">'.JText::_('REQUIRED').'</span>' : '';
 
@@ -624,7 +616,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 		}
 		$html .= '/> '.JText::_('Puerto Rican').'</label>'."\n";
 		$html .= "\t\t\t\t".'<label>'.JText::_('Other Hispanic or Latino').':'."\n";
-		$html .= "\t\t\t\t".'<input name="profile[hispanic][other]" id="hispanicother" type="text" value="'. $this->escape($hispanicother) .'" /></label>'."\n";
+		$html .= "\t\t\t\t".'<input name="profile[hispanic][other]" id="hispanicother" type="text" value="'. htmlentities($hispanicother,ENT_COMPAT,'UTF-8') .'" /></label>'."\n";
 		$html .= "\t\t\t".'</fieldset>'."\n";
 		$html .= "\t\t\t".'<label><input type="radio" class="option" name="hispanic" id="hispanicno" value="no"';
 		if (in_array('no', $hispanic)) {
@@ -641,7 +633,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 
 	// Race
 	if ($this->registration->Race != REG_HIDE) {
-		$message = (!empty($this->xregistration->_invalid['race'])) ? '<p class="error">' . $this->xregistration->_invalid['race'] . '</p>' : '';
+		$message = (!empty($this->xregistration->_invalid['race'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['race']) : '';
 		$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 		$required = ($this->registration->Race == REG_REQUIRED) ? ' <span class="required">'.JText::_('REQUIRED').'</span>' : '';
 
@@ -661,7 +653,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 		}
 		$html .= '/> '.JText::_('American Indian or Alaska Native').'</label>'."\n";
 		$html .= "\t\t\t".'<label class="indent">'.JText::_('Tribal Affiliation(s)').':'."\n";
-		$html .= "\t\t\t".'<input name="profile[nativetribe]" id="racenativetribe" type="text" value="'. $this->escape($this->profile->get('nativeTribe')) .'" /></label>'."\n";
+		$html .= "\t\t\t".'<input name="profile[nativetribe]" id="racenativetribe" type="text" value="'. htmlentities($this->profile->get('nativeTribe'),ENT_COMPAT,'UTF-8') .'" /></label>'."\n";
 		$html .= "\t\t\t".'<label><input type="checkbox" class="option" name="raceasian" id="raceasian" ';
 		if (in_array('asian', $race)) {
 			$html .= 'checked="checked" ';
@@ -696,7 +688,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 if ($this->registration->OptIn != REG_HIDE) // newsletter Opt-In
 {
 	$required = ($this->registration->OptIn == REG_REQUIRED) ? '<span class="required">'.JText::_('required').'</span>' : '';
-	$message = (!empty($this->xregistration->_invalid['mailPreferenceOption'])) ? '<p class="error">' . $this->xregistration->_invalid['mailPreferenceOption'] . '</p>' : '';
+	$message = (!empty($this->xregistration->_invalid['mailPreferenceOption'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['mailPreferenceOption']) : '';
 	$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 	$html .= "\t".'<fieldset>'."\n";
@@ -716,9 +708,9 @@ $html .= "<a name=\"memberpicture\"></a>";
 $html .= "\t\t".'<legend>'.JText::_('MEMBER_PICTURE').'</legend>'."\n";
 $html .= "\t\t".'<iframe width="100%" height="350" border="0" name="filer" id="filer" src="index.php?option='.$this->option.'&amp;controller=media&amp;tmpl=component&amp;file='.stripslashes($this->profile->get('picture')).'&amp;id='.$this->profile->get('uidNumber').'"></iframe>'."\n";
 $html .= "\t".'</fieldset><div class="clear"></div>'."\n";
-$html .= JHTML::_('form.token');
-$html .= "\t".'<p class="submit"><input class="btn btn-success" type="submit" name="submit" value="'.JText::_('SAVE').'" /></p>'."\n";
+
+$html .= "\t".'<p class="submit"><input type="submit" name="submit" value="'.JText::_('SAVE').'" /></p>'."\n";
 $html .= '</form>'."\n";
-$html .= '</section>'."\n";
+$html .= '</div>'."\n";
 
 echo $html;
