@@ -28,66 +28,67 @@
  * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  */
 
-namespace Hubzero\Bank;
+// Check to ensure this file is included in Joomla!
+defined('_JEXEC') or die('Restricted access');
 
 /**
  * Market History class:
  * Logs batch transactions, royalty distributions and other big transactions
  */
-class MarketHistory extends \JTable
+class Hubzero_Bank_MarketHistory extends JTable
 {
 	/**
 	 * int(11) Primary key
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $id          	= NULL;
 
 	/**
 	 * int(11)
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $itemid      	= NULL;
 
 	/**
 	 * varchar(50)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $category    	= NULL;
 
 	/**
 	 * decimal(11,2)
-	 *
+	 * 
 	 * @var number
 	 */
 	var $market_value	= NULL;
 
 	/**
 	 * datetime
-	 *
+	 * 
 	 * @var string
 	 */
 	var $date      		= NULL;
 
 	/**
 	 * varchar(50)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $action	 		= NULL;
 
 	/**
 	 * text
-	 *
+	 * 
 	 * @var string
 	 */
 	var $log    		= NULL;
 
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      object &$db JDatabase
 	 * @return     void
 	 */
@@ -96,38 +97,9 @@ class MarketHistory extends \JTable
 		parent::__construct('#__market_history', 'id', $db);
 	}
 
-	/**
-	 * Validate data
-	 *
-	 * @return     boolean True if data is valid
-	 */
-	public function check()
-	{
-		$this->itemid = intval($this->itemid);
-		if (!$this->itemid)
-		{
-			$this->setError(\JText::_('Entry must have an item ID.'));
-			return false;
-		}
-
-		$this->category = trim($this->category);
-		if (!$this->category)
-		{
-			$this->setError(\JText::_('Entry must have a category.'));
-			return false;
-		}
-
-		if (!$this->date)
-		{
-			$this->date = \JFactory::getDate()->toSql();
-		}
-
-		return true;
-	}
-
 	/**
 	 * Get the ID of a record matching the data passed
-	 *
+	 * 
 	 * @param      mixed  $itemid   Integer
 	 * @param      string $action   Transaction type
 	 * @param      string $category Transaction category
@@ -137,15 +109,15 @@ class MarketHistory extends \JTable
 	 */
 	public function getRecord($itemid=0, $action='', $category='', $created='', $log = '')
 	{
-		if ($itemid === NULL)
+		if ($itemid === NULL) 
 		{
 			$itemid = $this->itemid;
 		}
-		if ($action === NULL)
+		if ($action === NULL) 
 		{
 			$action = $this->action;
 		}
-		if ($category === NULL)
+		if ($category === NULL) 
 		{
 			$category = $this->category;
 		}
@@ -153,25 +125,25 @@ class MarketHistory extends \JTable
 		$sql = "SELECT id FROM $this->_tbl";
 
 		$where = array();
-		if ($itemid)
+		if ($itemid) 
 		{
-			$where[] = "itemid=" . $this->_db->Quote($itemid);
+			$where[] = " itemid='" . $itemid . "'";
 		}
-		if ($action)
+		if ($action) 
 		{
-			$where[] = "action=" . $this->_db->Quote($action);
+			$where[] = " AND action='" . $action . "'";
 		}
-		if ($category)
+		if ($category) 
 		{
-			$where[] = "category=" . $this->_db->Quote($category);
+			$where[] = " AND category='" . $category . "'";
 		}
-		if ($created)
+		if ($created) 
 		{
 			$where[] = "`date` LIKE '" . $created . "%'";
 		}
-		if ($log)
+		if ($log) 
 		{
-			$where[] = "log=" . $this->_db->Quote($log);
+			$where[] = "log='" . $log . "'";
 		}
 		if (count($where) > 0)
 		{
