@@ -35,38 +35,98 @@ defined('_JEXEC') or die('Restricted access');
 /**
  * Module class for displaying a quick contact form
  */
-class modRapidContact extends \Hubzero\Module\Module
+class modRapidContact extends JObject
 {
+	/**
+	 * Container for properties
+	 * 
+	 * @var array
+	 */
+	private $attributes = array();
+
+	/**
+	 * Constructor
+	 * 
+	 * @param      object $this->params JParameter
+	 * @param      object $module Database row
+	 * @return     void
+	 */
+	public function __construct($params, $module)
+	{
+		$this->params = $params;
+		$this->module = $module;
+	}
+
+	/**
+	 * Set a property
+	 * 
+	 * @param      string $property Name of property to set
+	 * @param      mixed  $value    Value to set property to
+	 * @return     void
+	 */
+	public function __set($property, $value)
+	{
+		$this->attributes[$property] = $value;
+	}
+
+	/**
+	 * Get a property
+	 * 
+	 * @param      string $property Name of property to retrieve
+	 * @return     mixed
+	 */
+	public function __get($property)
+	{
+		if (isset($this->attributes[$property])) 
+		{
+			return $this->attributes[$property];
+		}
+	}
+
+	/**
+	 * Check if a property is set
+	 * 
+	 * @param      string $property Property to check
+	 * @return     boolean True if set
+	 */
+	public function __isset($property)
+	{
+		return isset($this->_attributes[$property]);
+	}
+
 	/**
 	 * Display module content
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function display()
 	{
+		ximport('Hubzero_Document');
+		Hubzero_Document::addModuleStylesheet('mod_rapid_contact');
+
 		// Field labels
-		$this->name_label    = $this->params->get('name_label', JText::_('MOD_RAPID_CONTACT_FIELD_NAME'));
-		$this->email_label   = $this->params->get('email_label', JText::_('MOD_RAPID_CONTACT_FIELD_EMAIL'));
-		$this->subject_label = $this->params->get('subject_label', JText::_('MOD_RAPID_CONTACT_FIELD_SUBJECT'));
-		$this->message_label = $this->params->get('message_label', JText::_('MOD_RAPID_CONTACT_FIELD_MESSAGE'));
+		$this->name_label    = $this->params->get('name_label', 'Name:');
+		$this->email_label   = $this->params->get('email_label', 'Email:');
+		$this->subject_label = $this->params->get('subject_label', 'Subject:');
+		$this->message_label = $this->params->get('message_label', 'Message:');
 
 		// Button text
-		$this->button_text   = $this->params->get('button_text', JText::_('MOD_RAPID_CONTACT_SEND'));
+		$this->button_text   = $this->params->get('button_text', 'Send Message');
 
 		// Pre text
 		$this->pre_text      = $this->params->get('pre_text', '');
 
 		// Thank you message
-		$this->page_text     = $this->params->get('page_text', JText::_('MOD_RAPID_CONTACT_THANK_YOU'));
+		$this->page_text     = $this->params->get('page_text', 'Thank you for your contact.');
 
 		// Error messages
-		$this->error_text    = $this->params->get('error_text', JText::_('MOD_RAPID_CONTACT_ERROR_SENDING'));
-		$this->no_email      = $this->params->get('no_email', JText::_('MOD_RAPID_CONTACT_ERROR_NO_EMAIL'));
-		$this->invalid_email = $this->params->get('invalid_email', JText::_('MOD_RAPID_CONTACT_ERROR_INVALID_EMAIL'));
+		$this->error_text    = $this->params->get('error_text', 'Your message could not be sent. Please try again.');
+		$this->no_email      = $this->params->get('no_email', 'Please write your email');
+	    $this->invalid_email = $this->params->get('invalid_email', 'Please write a valid email');
 
 		// From
-		$jconfig = JFactory::getConfig();
-		$this->from_name     = @$this->params->get('from_name', JText::_('MOD_RAPID_CONTACT'));
+		$jconfig =& JFactory::getConfig();
+		$this->from_name     = @$this->params->get('from_name', 'Rapid Contact');
 		$this->from_email    = @$this->params->get('from_email', 'rapid_contact@yoursite.com');
 
 		// To
@@ -78,36 +138,31 @@ class modRapidContact extends \Hubzero\Module\Module
 
 		// Enable Anti-spam?
 		$this->enable_anti_spam = $this->params->get('enable_anti_spam', true);
-		$this->anti_spam_q   = $this->params->get('anti_spam_q', JText::_('MOD_RAPID_CONTACT_ANTIPSAM'));
+		$this->anti_spam_q   = $this->params->get('anti_spam_q', 'How many eyes has a typical person?');
 		$this->anti_spam_a   = $this->params->get('anti_spam_a', '2');
 
-		$this->mod_class_suffix = $this->params->get('moduleclass_sfx', '');
+	    $this->mod_class_suffix = $this->params->get('moduleclass_sfx', '');
 
 		$disable_https       = $this->params->get('disable_https', false);
 		$exact_url           = $this->params->get('exact_url', true);
-		if (!$exact_url)
+		if (!$exact_url) 
 		{
-			//$this->url = $this->_cleanXss(filter_var(JURI::current(), FILTER_SANITIZE_URL));
 			$this->url = JURI::current();
-		}
-		else
+		} 
+		else 
 		{
-			if (!$disable_https)
+			if (!$disable_https) 
 			{
 				$this->url = (!empty($_SERVER['HTTPS'])) ? 'https://' . $_SERVER['SERVER_NAME'] . $_SERVER['REQUEST_URI'] : 'http://' . $_SERVER['SERVER_NAME'] . $_SERVER['REQUEST_URI'];
-			}
-			else
+			} 
+			else 
 			{
 				$this->url = 'http://' . $_SERVER['SERVER_NAME'] . $_SERVER['REQUEST_URI'];
 			}
 		}
 
-		//$qs = str_replace(array('"', '?'), '', urldecode($_SERVER['QUERY_STRING']));
-		//$aqs = explode('?', $this->url);
-		//$this->url = $aqs[0] . '?' . urlencode($qs);
-
 		$fixed_url = $this->params->get('fixed_url', true);
-		if ($fixed_url)
+		if ($fixed_url) 
 		{
 			$this->url = $this->params->get('fixed_url_address', '');
 		}
@@ -122,47 +177,45 @@ class modRapidContact extends \Hubzero\Module\Module
 			'message' => ''
 		);
 
-		if (isset($_POST['rp']))
+		if (isset($_POST['rp'])) 
 		{
-			$this->posted = JRequest::getVar('rp', array(), 'post');
+			$this->posted = $_POST['rp'];
 
-			if ($this->enable_anti_spam)
+			if ($this->enable_anti_spam) 
 			{
-				if (!isset($this->posted['anti_spam_answer']) || ($this->posted['anti_spam_answer'] != $this->anti_spam_a))
+				if ($_POST['rp']['anti_spam_answer'] != $this->anti_spam_a) 
 				{
-					$this->error = JText::_('MOD_RAPID_CONTACT_INVALID_ANTIPSAM_ANSWER');
+					$this->error = JText::_('Wrong anti-spam answer');
 				}
 			}
-			if ($this->posted['email'] === '')
+			if ($_POST['rp']['email'] === '') 
 			{
 				$this->error = $this->no_email;
 			}
-			if (!preg_match("#^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})$#i", $this->posted['email']))
+			if (!preg_match("#^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})$#i", $_POST['rp']['email'])) 
 			{
 				$this->error = $this->invalid_email;
 			}
-
-			if ($this->error == '')
+			if ($this->error == '') 
 			{
-				$mySubject = \Hubzero\Utility\Sanitize::clean($this->posted['subject']);
-				$myMessage  = JText::sprintf('MOD_RAPID_CONTACT_MESSAGE_FROM', $this->posted['name'], $this->posted['email'], JRequest::getVar('HTTP_REFERER', '', 'SERVER'), $jconfig->getValue('config.sitename'));
-				$myMessage .= "\n\n". \Hubzero\Utility\Sanitize::clean($this->posted['message']);
+				$mySubject = $_POST['rp']['subject'];
+				$myMessage = 'You received a message from '. $_POST['rp']['email'] ."\n\n". $_POST['rp']['message'];
 
-				$this->from_email = $this->posted['email'];
-				$this->from_name  = (isset($this->posted['name']) && \Hubzero\Utility\Sanitize::clean($this->posted['name'])) ? \Hubzero\Utility\Sanitize::clean($this->posted['name']) : $this->posted['email'];
+				$this->from_email = $_POST['rp']['email'];
+				$this->from_name  = (isset($_POST['rp']['name']) && $_POST['rp']['name']) ? $_POST['rp']['name'] : $_POST['rp']['email'];
 
-				$mailSender = new \Hubzero\Mail\Message();
-				$mailSender->setSubject($mySubject)
-				           ->addFrom($this->from_email, $this->from_name)
-				           ->addTo($this->recipient)
-				           ->addReplyTo($this->posted['email'], $this->posted['name'])
-				           ->setBody($myMessage);
+				$mailSender = &JFactory::getMailer();
+				$mailSender->addRecipient($this->recipient);
+				$mailSender->setSender(array($this->from_email, $this->from_name));
+				$mailSender->addReplyTo(array($_POST['rp']['email'], ''));
+				$mailSender->setSubject($mySubject);
+				$mailSender->setBody($myMessage);
 
-				if (!$mailSender->send())
+				if (!$mailSender->Send()) 
 				{
 					$this->error = $this->error_text;
-				}
-				else
+				} 
+				else 
 				{
 					$this->replacement = $this->page_text;
 				}
