@@ -32,54 +32,55 @@ defined('_JEXEC') or die('Restricted access');
 /**
  * Groups Plugin class for projects
  */
-class plgGroupsProjects extends \Hubzero\Plugin\Plugin
+class plgGroupsProjects extends JPlugin
 {
-	/**
-	 * Affects constructor behavior. If true, language files will be loaded automatically.
-	 *
-	 * @var    boolean
-	 */
-	protected $_autoloadLanguage = true;
-
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      object &$subject Event observer
 	 * @param      array  $config   Optional config values
 	 * @return     void
 	 */
-	public function __construct(&$subject, $config)
+	public function __construct(&$subject, $config) 
 	{
 		parent::__construct($subject, $config);
 
-		$this->_config = JComponentHelper::getParams('com_projects');
-		$this->_database = JFactory::getDBO();
+		$this->loadLanguage();
+
+		$paramsClass = 'JParameter';
+		if (version_compare(JVERSION, '1.6', 'ge'))
+		{
+			$paramsClass = 'JRegistry';
+		}
+
+		// Load plugin parameters
+		$this->_plugin = JPluginHelper::getPlugin('groups', 'projects');
+		$this->_params = new $paramsClass($this->_plugin->params);
+		$this->_config =& JComponentHelper::getParams('com_projects');
+		$this->_database =& JFactory::getDBO();
 		$this->_setup_complete = $this->_config->get('confirm_step', 0) ? 3 : 2;
-		$this->_juser = JFactory::getUser();
-		$this->_total = 0;
-		$this->_projects = array();
+		$this->_juser =& JFactory::getUser();
 	}
 
 	/**
 	 * Return the alias and name for this category of content
-	 *
+	 * 
 	 * @return     array
 	 */
-	public function &onGroupAreas()
+	public function &onGroupAreas() 
 	{
 		$area = array(
-			'name'             => $this->_name,
-			'title'            => JText::_('PLG_GROUPS_PROJECTS'),
-			'default_access'   => $this->params->get('plugin_access','members'),
-			'display_menu_tab' => $this->params->get('display_tab', 1),
-			'icon'             => 'f03f'
+			'name' => 'projects',
+			'title' => JText::_('PLG_GROUPS_PROJECTS'),
+			'default_access' => 'members',
+			'display_menu_tab' => true
 		);
 		return $area;
 	}
 
 	/**
 	 * Return data on a group view (this will be some form of HTML)
-	 *
+	 * 
 	 * @param      object  $group      Current group
 	 * @param      string  $option     Name of the component
 	 * @param      string  $authorized User's authorization level
@@ -90,51 +91,36 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 	 * @param      array   $areas      Active area(s)
 	 * @return     array
 	 */
-	public function onGroup($group, $option, $authorized, $limit=0, $limitstart=0, $action='', $access, $areas=null)
+	public function onGroup($group, $option, $authorized, $limit=0, $limitstart=0, $action='', $access, $areas=null) 
 	{
 		$return = 'html';
-		$active = $this->_name;
+		$active = 'projects';
 
 		// The output array we're returning
 		$arr = array(
-			'html'     => '',
-			'metadata' => ''
+			'html' => ''
 		);
 
 		//get this area details
 		$this_area = $this->onGroupAreas();
 
 		// Check if our area is in the array of areas we want to return results for
-		if (is_array($areas) && $limit)
+		if (is_array($areas) && $limit) 
 		{
-			if (!in_array($this_area['name'], $areas))
+			if (!in_array($this_area['name'], $areas)) 
 			{
 				$return = 'metadata';
 			}
 		}
 
-		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components'
-			. DS . 'com_projects' . DS . 'tables' . DS . 'project.php');
-		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components'
-			. DS . 'com_projects' . DS . 'tables' . DS . 'project.owner.php');
-
-		// Set filters
-		$filters = array();
-		$filters['group']  = $group->get('gidNumber');
-		$filters['mine']     = 1;
-
-		// Get a record count
-		$obj = new Project($this->_database);
-		$this->_projects = $obj->getGroupProjectIds($group->get('gidNumber'), $this->_juser->get('id'));
-
 		//if we want to return content
-		if ($return == 'html')
+		if ($return == 'html') 
 		{
 			//set group members plugin access level
 			$group_plugin_acl = $access[$active];
 
 			//Create user object
-			$juser = JFactory::getUser();
+			$juser =& JFactory::getUser();
 
 			//get the group members
 			$members = $group->get('members');
@@ -148,42 +134,43 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 			$this->action     = $action;
 
 			//if set to nobody make sure cant access
-			if ($group_plugin_acl == 'nobody')
+			if ($group_plugin_acl == 'nobody') 
 			{
 				$arr['html'] = '<p class="info">' . JText::sprintf('GROUPS_PLUGIN_OFF', ucfirst($active)) . '</p>';
 				return $arr;
 			}
 
 			//check if guest and force login if plugin access is registered or members
-			if ($juser->get('guest')
-			 && ($group_plugin_acl == 'registered' || $group_plugin_acl == 'members'))
+			if ($juser->get('guest') 
+			 && ($group_plugin_acl == 'registered' || $group_plugin_acl == 'members')) 
 			{
-				$url = JRoute::_('index.php?option=com_groups&cn='.$group->get('cn').'&active='.$active, false, true);
-
-				$this->redirect(
-					JRoute::_('index.php?option=com_users&view=login&return=' . base64_encode($url)),
-					JText::sprintf('GROUPS_PLUGIN_REGISTERED', ucfirst($active)),
-					'warning'
-				);
-				return;
-			}
-
-			//check to see if user is member and plugin access requires members
-			if (!in_array($juser->get('id'), $members) && $group_plugin_acl == 'members' && $authorized != 'admin')
-			{
-				$arr['html'] = '<p class="info">'
-					. JText::sprintf('GROUPS_PLUGIN_REQUIRES_MEMBER', ucfirst($active)) . '</p>';
+				ximport('Hubzero_Module_Helper');
+				$arr['html']  = '<p class="warning">' . JText::sprintf('GROUPS_PLUGIN_REGISTERED', ucfirst($active)) . '</p>';
+				$arr['html'] .= Hubzero_Module_Helper::renderModules('force_mod');
 				return $arr;
 			}
 
+			//check to see if user is member and plugin access requires members
+			if (!in_array($juser->get('id'), $members) && $group_plugin_acl == 'members' && $authorized != 'admin') 
+			{
+				$arr['html'] = '<p class="info">' . JText::sprintf('GROUPS_PLUGIN_REQUIRES_MEMBER', ucfirst($active)) . '</p>';
+				return $arr;
+			}
+
+			//push styles to the view
+			ximport('Hubzero_Document');
+			Hubzero_Document::addPluginStylesheet('groups', 'projects');
+
 			// Load classes
+			require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_projects' . DS . 'tables' . DS . 'project.php');
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_projects' . DS . 'helpers' . DS . 'html.php');
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_projects' . DS . 'helpers' . DS . 'imghandler.php');
+			ximport('Hubzero_View_Helper_Html');
 
-			// Which view
+			// Which view 
 			$task = $action ? strtolower(trim($action)) : JRequest::getVar('action', '');
 
-			switch ($task)
+			switch ($task) 
 			{
 				case 'all':     $arr['html'] = $this->_view('all');   break;
 				case 'owned':   $arr['html'] = $this->_view('owned'); break;
@@ -192,52 +179,17 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 			}
 		}
 
-		//get meta
-		$arr['metadata'] = array();
-
-		//return total message count
-		$arr['metadata']['count'] = count($this->_projects);
-
 		// Return the output
 		return $arr;
 	}
 
-	/**
-	 * On after group membership changes - re-sync with projects
-	 *
-	 * @param      object  $group      Current group
-	 * @return     array
-	 */
-	public function onAfterStoreGroup($group)
-	{
-		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components'
-			. DS . 'com_projects' . DS . 'tables' . DS . 'project.php');
-		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components'
-			. DS . 'com_projects' . DS . 'tables' . DS . 'project.owner.php');
-
-		// Get group projects
-		$obj  = new Project($this->_database);
-		$objO = new ProjectOwner( $this->_database );
-		$projects = $obj->getGroupProjects($group->get('gidNumber'), $this->_juser->get('id'));
-
-		// Project-group sync
-		if ($projects)
-		{
-			foreach ($projects as $project)
-			{
-				$objO->reconcileGroups($project->id, $project->owned_by_group);
-				$objO->sysGroup($project->alias, $this->_config->get('group_prefix', 'pr-'));
-			}
-		}
-	}
-
 	/**
 	 * View entries
-	 *
+	 * 
 	 * @param      string $which The type of entries to display
 	 * @return     string
 	 */
-	protected function _view($which = 'owned')
+	protected function _view($which = 'owned') 
 	{
 		// Set filters
 		$filters = array();
@@ -248,7 +200,8 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 		$filters['sortdir']  = JRequest::getVar('sortdir', 'DESC');
 
 		// Build the final HTML
-		$view = new \Hubzero\Plugin\View(
+		ximport('Hubzero_Plugin_View');
+		$view = new Hubzero_Plugin_View(
 			array(
 				'folder'  => 'groups',
 				'element' => 'projects',
@@ -257,32 +210,30 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 		);
 
 		$obj = new Project($this->_database);
-		if ($which == 'all')
+		if ($which == 'all') 
 		{
 			$filters['which'] = 'owned';
-			$view->owned = $obj->getGroupProjects($this->group->get('gidNumber'),
-				$this->_juser->get('id'), $filters, $this->_setup_complete);
+			$view->owned = $obj->getGroupProjects($this->group->get('gidNumber'), $this->_juser->get('id'), $filters, $this->_setup_complete);
 
 			$filters['which'] = 'other';
-			$view->rows = $obj->getGroupProjects($this->group->get('gidNumber'),
-				$this->_juser->get('id'), $filters, $this->_setup_complete);
+			$view->rows = $obj->getGroupProjects($this->group->get('gidNumber'), $this->_juser->get('id'), $filters, $this->_setup_complete);
 		}
-		else
+		else 
 		{
 			// Get records
 			$options = array('all', 'owned', 'other');
-			if (!in_array($which, $options))
+			if (!in_array($which, $options)) 
 			{
 				$which = 'owned';
 			}
 			$filters['which'] = $which;
-			$view->rows = $obj->getGroupProjects($this->group->get('gidNumber'),
-				$this->_juser->get('id'), $filters, $this->_setup_complete);
+			$view->rows = $obj->getGroupProjects($this->group->get('gidNumber'), $this->_juser->get('id'), $filters, $this->_setup_complete);
 		}
 
 		// Get counts
-		$view->projectcount = count($this->_projects);
-		$view->newcount = $obj->getUpdateCount ($this->_projects, $this->_juser->get('id'));
+		$projects = $obj->getGroupProjectIds($this->group->get('gidNumber'), $this->_juser->get('id'));
+		$view->projectcount = count($projects);
+		$view->newcount = $obj->getUpdateCount ($projects, $this->_juser->get('id'));
 
 		$view->which   = $which;
 		$view->juser   = $this->_juser;
@@ -290,7 +241,7 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 		$view->config  = $this->_config;
 		$view->option  = 'com_projects';
 		$view->group   = $this->group;
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			$view->setError($this->getError());
 		}
@@ -300,17 +251,18 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Display updates
-	 *
+	 * 
 	 * @return     string
 	 */
-	protected function _updates()
+	protected function _updates() 
 	{
 		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_projects' . DS . 'tables' . DS . 'project.comment.php');
 		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_projects' . DS . 'tables' . DS . 'project.todo.php');
 		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_projects' . DS . 'tables' . DS . 'project.microblog.php');
 
 		// Build the final HTML
-		$view = new \Hubzero\Plugin\View(
+		ximport('Hubzero_Plugin_View');
+		$view = new Hubzero_Plugin_View(
 			array(
 				'folder'  => 'groups',
 				'element' => 'projects',
@@ -326,13 +278,12 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 		$filters['getowner'] = 1;
 		$filters['sortdir']  = JRequest::getVar('sortdir', 'ASC');
 
-		// Get all projects group has access to
-		$obj = new Project($this->_database);
+		// Get all projects group has access to	
+		$obj = new Project($this->_database);	
 		$projects = $obj->getGroupProjectIds($this->group->get('gidNumber'), $this->_juser->get('id'));
 		$view->projectcount = count($projects);
 
-		$projects = $obj->getGroupProjectIds($this->group->get('gidNumber'),
-			$this->_juser->get('id'), 1); // active only
+		$projects = $obj->getGroupProjectIds($this->group->get('gidNumber'), $this->_juser->get('id'), 1); // active only
 		$view->newcount = $obj->getUpdateCount($projects, $this->_juser->get('id'));
 
 		// Get activity class
@@ -344,18 +295,17 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 		$view->limit = 25;
 
 		$afilters['limit'] = JRequest::getVar('limit', 25, 'request');
-		$view->filters = $afilters;
+		$view->filters = $afilters;	
 
 		$activities = $objAC->getActivities(0, $afilters, 0, $this->_juser->get('id'), $projects);
-		$view->activities = $this->prepActivities($activities, 'com_projects',
-			$this->_juser->get('id'), $view->filters, $view->limit);
+		$view->activities = $this->prepActivities($activities, 'com_projects', $this->_juser->get('id'), $view->filters, $view->limit);
 
 		$view->uid      = $this->_juser->get('id');
 		$view->config   = $this->_config;
 		$view->option   = 'com_projects';
 		$view->database = $this->_database;
 		$view->group    = $this->group;
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			$view->setError($this->getError());
 		}
@@ -365,7 +315,7 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * View entries
-	 *
+	 * 
 	 * @param      string  $activities The type of entries to display
 	 * @param      string  $option     Component name
 	 * @param      integer $uid        User ID
@@ -388,12 +338,12 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 		$prep    = array();
 
 		// Loop through activities
-		if ($activities && count($activities) > 0)
+		if ($activities && count($activities) > 0) 
 		{
-			foreach ($activities as $a)
-			{
+			foreach ($activities as $a) 
+			{ 
 				// Is this a comment?
-				if ($a->class == 'quote')
+				if ($a->class == 'quote') 
 				{
 					// Get comment
 					$c = $objC->getComments(NULL, NULL, $a->id);
@@ -402,31 +352,31 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 					$needle  = array('id' => $c->parent_activity);
 					$key     = ProjectsHTML::myArraySearch($needle, $activities);
 					$shown[] = $a->id;
-					if (!$key)
+					if (!$key) 
 					{
 						// get and add parent activity
 						$filters['id'] = $c->parent_activity;
 						$pa = $objAC->getActivities($a->projectid, $filters, 0, $uid);
-						if ($pa && count($pa) > 0)
+						if ($pa && count($pa) > 0) 
 						{
 							$a = $pa[0];
 						}
 					}
-					else
+					else 
 					{
-						$a = $activities[$key];
+						$a = $activities[$key]; 
 					}
 					$a->new = isset($c->newcount) ? $c->newcount : 0;
 				}
 
-				if (!in_array($a->id, $shown))
+				if (!in_array($a->id, $shown)) 
 				{
 					$shown[]   = $a->id;
 					$class     = $a->class ? $a->class : 'activity';
 					$timeclass = '';
 
 					// Display hyperlink
-					if ($a->highlighted && $a->url)
+					if ($a->highlighted && $a->url) 
 					{
 						$a->activity = str_replace($a->highlighted, '<a href="' . $a->url . '">' . $a->highlighted . '</a>', $a->activity);
 					}
@@ -438,10 +388,10 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 					$deletable = 0;
 
 					// Get blog entry
-					if ($class == 'blog')
+					if ($class == 'blog') 
 					{
 						$blog = $objM->getEntries($a->projectid, $bfilters = array('activityid' => $a->id), $a->referenceid);
-						if (!$blog)
+						if (!$blog) 
 						{
 							continue;
 						}
@@ -452,10 +402,10 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 					}
 
 					// Get todo item
-					if ($class == 'todo')
+					if ($class == 'todo') 
 					{
 						$todo = $objTD->getTodos($a->projectid, $tfilters = array('activityid' => $a->id), $a->referenceid);
-						if (!$todo)
+						if (!$todo) 
 						{
 							continue;
 						}
@@ -466,7 +416,7 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 					}
 
 					// Embed links
-					if ($body)
+					if ($body) 
 					{
 						$body = ProjectsHTML::replaceUrls($body, 'external');
 					}
@@ -477,11 +427,11 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 					$ebody .= $body ? '">' . $body . '</span>' : '';
 
 					// Get comments
-					if ($a->commentable)
+					if ($a->commentable) 
 					{
 						$comments = $objC->getComments($eid, $etbl);
 					}
-					else
+					else 
 					{
 						$comments = null;
 					}
@@ -490,7 +440,7 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 					$deletable = 0;
 
 					$prep[] = array(
-						'activity' => $a, 'eid' => $eid, 'etbl' => $etbl, 'body' => $ebody, 'deletable' => $deletable, 'comments' => $comments,
+						'activity' => $a, 'eid' => $eid, 'etbl' => $etbl, 'body' => $ebody, 'deletable' => $deletable, 'comments' => $comments, 
 						'class' => $class, 'timeclass' => $timeclass, 'projectid' => $a->projectid, 'recorded' => $a->recorded
 					);
 				}
@@ -498,24 +448,25 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 		}
 
 		return $prep;
-	}
+	} 
 
 	/**
 	 * Browse entries
-	 *
+	 * 
 	 * @return     string
 	 */
 	private function browse()
 	{
 		//include a project helper file for handing project picture
 		$include = JPATH_ROOT . DS . 'components' . DS . 'com_projects' . DS . 'helpers' . DS . 'imghandler.php';
-		if (is_file($include))
+		if (is_file($include)) 
 		{
 			include_once($include);
 		}
 
 		//create plugin view
-		$view = new \Hubzero\Plugin\View(
+		ximport('Hubzero_Plugin_View');
+		$view = new Hubzero_Plugin_View(
 			array(
 				'folder'  => 'groups',
 				'element' => 'projects',
@@ -524,32 +475,32 @@ class plgGroupsProjects extends \Hubzero\Plugin\Plugin
 		);
 
 		//instatiate db
-		$db = JFactory::getDBO();
+		$db =& JFactory::getDBO();
 
 		//select all projects either belonging to the group or the group is collaborating on
 		$sql = "SELECT DISTINCT
 					p.id as id,
-					p.alias as alias,
-					p.title as title,
-					p.picture as picture,
+					p.alias as alias, 
+					p.title as title, 
+					p.picture as picture, 
 					p.type as type,
 					p.private as private,
 					p.created as created,
 					p.owned_by_user as owned_by_user,
 					p.owned_by_group as owned_by_group
-				FROM #__projects as p, #__project_owners as po
-				WHERE p.id=po.projectid
-				AND p.state=1
+				FROM #__projects as p, #__project_owners as po 
+				WHERE p.id=po.projectid 
+				AND p.state=1 
 				AND po.groupid=" . $db->quote($this->group->get('gidNumber')) . " ORDER BY p.owned_by_group DESC";
 
 		//set the query
 		$db->setQuery($sql);
 
-		//get the results
+		//get the results 
 		$projects = $db->loadAssocList();
 
 		// Get the component parameters
-		$view->project_params = JComponentHelper::getParams('com_projects');
+		$view->project_params =& JComponentHelper::getParams('com_projects');
 
 		//push vars to the view
 		$view->projects = $projects;
